@@ -9,8 +9,9 @@ import os
 import visdcc
 import base64
 import pandas as pd
-import dash_core_components as dcc
-import dash_html_components as html
+from dash import dcc, html
+# import dash_core_components as dcc
+# import dash_html_components as html
 import dash_bootstrap_components as dbc
 
 # Constants
